1
0
mirror of https://git.FreeBSD.org/ports.git synced 2024-12-23 04:23:08 +00:00

- Update to 0.10

PR:		139521
Submitted by:	Ports Fury
This commit is contained in:
Martin Wilke 2009-10-14 13:45:30 +00:00
parent e27c0ed4e8
commit 7427327972
Notes: svn2git 2021-03-31 03:12:20 +00:00
svn path=/head/; revision=242840
3 changed files with 15 additions and 16 deletions

View File

@ -6,7 +6,7 @@
#
PORTNAME= pqiv
PORTVERSION= 0.9
PORTVERSION= 0.10
CATEGORIES= graphics
MASTER_SITES= http://www.pberndt.com/raw/Programme/Linux/pqiv/_download/
EXTRACT_SUFX= .tbz

View File

@ -1,3 +1,3 @@
MD5 (pqiv-0.9.tbz) = 15bb82cf22af0d3fbd74ce9481ea503b
SHA256 (pqiv-0.9.tbz) = 21bb2bf3c5fefc5882432cbde9540e18292ed8f021afc279195639ed16a56e75
SIZE (pqiv-0.9.tbz) = 31821
MD5 (pqiv-0.10.tbz) = aa476483b9e50a874b8693ae19cf7d4d
SHA256 (pqiv-0.10.tbz) = 1f00846d45e13395a44483be053fc6cd1e4e9946fd2e89769956044d1369b338
SIZE (pqiv-0.10.tbz) = 31971

View File

@ -1,5 +1,5 @@
--- pqiv.c.orig 2009-05-06 06:10:47.000000000 +0900
+++ pqiv.c 2009-09-02 02:26:40.000000000 +0900
--- pqiv.c.orig 2009-10-08 19:49:20.000000000 +0900
+++ pqiv.c 2009-10-10 17:43:14.000000000 +0900
@@ -234,7 +234,7 @@
}}}
*/
@ -9,7 +9,7 @@
"\n");
if(claim != 0) {
g_print("I don't understand the meaning of %c\n\n", claim);
@@ -272,7 +272,7 @@
@@ -273,7 +273,7 @@
#ifndef NO_COMMANDS
" -<n> s Set command number n (1-9) to s \n"
" See manpage for advanced commands (starting with > or |) \n"
@ -18,7 +18,7 @@
#endif
"\n"
@@ -296,7 +296,7 @@
@@ -297,7 +297,7 @@
" v Vertical flip \n"
" i Show/hide info box \n"
" s Slideshow toggle \n"
@ -27,7 +27,7 @@
#ifndef NO_COMMANDS
" <n> Run command n (1-3) \n"
#endif
@@ -1824,12 +1824,12 @@
@@ -1737,12 +1737,12 @@
}
break;
/* }}} */
@ -43,10 +43,10 @@
+ sprintf(buf, "./." BINARY_NAME "-select/%s", buf2);
if(link(currentFile->fileName, buf) != 0) {
/* Failed to link image, try copying it */
if(copyFile(currentFile->fileName, buf) != 0) {
@@ -2253,14 +2253,14 @@
optionCommands[i] = (char*)g_malloc(strlen(optarg) + 1);
strcpy(optionCommands[i], optarg);
if(copyFile(currentFile->fileName, buf) != TRUE) {
@@ -2214,13 +2214,13 @@
}
optionCommands[i] = g_strdup((gchar*)optarg);
break;
/* OPTION: -q: Use the qiv-command script for commands */
@ -55,9 +55,8 @@
if(optionCommands[i] != NULL) {
g_free(optionCommands[i]);
}
optionCommands[i] = (char*)g_malloc(14);
- memcpy(optionCommands[i], "qiv-command 0", 14);
+ memcpy(optionCommands[i], BINARY_NAME "-command 0", 14);
- optionCommands[i] = g_strdup("qiv-command 0");
+ optionCommands[i] = g_strdup(BINARY_NAME "-command 0");
optionCommands[i][12] += i;
}
break;
@@ -2214,13 +2214,13 @@
optionCommands[i] = g_strdup((gchar*)optarg);
break;
- /* OPTION: -q: Use the qiv-command script for commands */
+ /* OPTION: -q: Use the BINARY_NAME-command script for commands */
if(optionCommands[i] != NULL) {